package nl.kallestruik.dtweaks.tweaks.croptweaks

import nl.kallestruik.dtweaks.tweaks.ITweak
import org.bukkit.Material
import org.bukkit.block.data.Ageable
import org.bukkit.event.EventHandler
import org.bukkit.event.HandlerList
import org.bukkit.event.Listener
import org.bukkit.event.block.BlockBreakEvent
import org.bukkit.plugin.java.JavaPlugin

class HoeHarvestArea(
    private val plugin: JavaPlugin
): ITweak, Listener {
    override fun getIdentifier(): String = "HoesHarvestArea"
    override fun getCategories(): List<String> = listOf("crops", "survival")

    override fun onEnable() {
        plugin.server.pluginManager.registerEvents(this, plugin)
    }

    override fun onDisable() {
        HandlerList.unregisterAll(this)
    }

    @EventHandler
    fun onHoeBreaksBlock(event: BlockBreakEvent) {
        val player = event.player
        val block = event.block
        val world = block.world
        val itemInHand = player.inventory.itemInMainHand
        val range = when(itemInHand.type) {
            Material.WOODEN_HOE -> 1
            Material.STONE_HOE -> 1
            Material.IRON_HOE -> 1
            Material.GOLDEN_HOE -> 1
            Material.DIAMOND_HOE -> 2
            Material.NETHERITE_HOE -> 2
            else -> return
        }

        if (!isCrop(block.type)) return

        val startLocation = block.location
        for (x in -range..range) {
            for (z in -range..range) {
                val b = world.getBlockAt(startLocation.clone().add(x.toDouble(), 0.0, z.toDouble()))
                if (isCrop(b.type)) {
                    val ageable = b.blockData as Ageable
                    if (ageable.age == ageable.maximumAge) {
                        b.breakNaturally()
                    }
                }
            }
        }
    }


    private fun isCrop(material: Material): Boolean {
        return material == Material.WHEAT || material == Material.BEETROOTS || material == Material.CARROTS || material == Material.POTATOES
    }
}