package nl.kallestruik.dtweaks.tweaks.croptweaks

import nl.kallestruik.dtweaks.tweaks.ITweak
import org.bukkit.Bukkit
import org.bukkit.Material
import org.bukkit.Particle
import org.bukkit.World
import org.bukkit.block.Block
import org.bukkit.entity.Item
import org.bukkit.event.Listener
import org.bukkit.plugin.java.JavaPlugin
import org.bukkit.scheduler.BukkitTask

class SeedDropPlanting(
    private val plugin: JavaPlugin
): ITweak, Listener {
    private lateinit var task: BukkitTask

    override fun getIdentifier(): String = "SeedDropPlanting"
    override fun getCategories(): List<String> = listOf("crops", "survival")

    override fun onEnable() {
        task = Bukkit.getScheduler().runTaskTimer(plugin, SeedPlantTask(plugin), (20 * 10).toLong(), (20 * 10).toLong())
    }

    override fun onDisable() {
        task.cancel()
    }

    private class SeedPlantTask(
        private val plugin: JavaPlugin
    ): Runnable {
        override fun run() {
            for (world in plugin.server.worlds) {
                for (entity in world.entities) {
                    if (entity is Item) {
                        val b = world.getBlockAt(entity.location)
                        val above = world.getBlockAt(entity.location.add(0.0, 1.0, 0.0))
                        if (b.type == Material.FARMLAND && above.type == Material.AIR) {
                            when (entity.itemStack.type) {
                                Material.WHEAT_SEEDS -> plantSeed(entity, world, above, Material.WHEAT)
                                Material.BEETROOT_SEEDS -> plantSeed(entity, world, above, Material.BEETROOTS)
                                Material.MELON_SEEDS -> plantSeed(entity, world, above, Material.MELON_STEM)
                                Material.PUMPKIN_SEEDS -> plantSeed(entity, world, above, Material.PUMPKIN_STEM)
                                Material.POTATO -> plantSeed(entity, world, above, Material.POTATOES)
                                Material.CARROT -> plantSeed(entity, world, above, Material.CARROTS)
                                else -> continue
                            }
                        }
                    }
                }
            }
        }

        private fun plantSeed(entity: Item, world: World, block: Block, material: Material) {
            block.type = material
            world.spawnParticle(Particle.VILLAGER_HAPPY, entity.location, 10)
            if (entity.itemStack.amount == 1) {
                entity.remove()
            } else {
                entity.itemStack.amount = entity.itemStack.amount - 1
            }
        }
    }
}